@@ -25,14 +25,34 @@ SUPPORTED_DEVICES = glob.glob(
 )
 
 
-LIGHT_STRIPS = {"KL430"}
-VARIABLE_TEMP = {"LB120", "LB130", "KL120", "KL125", "KL130", "KL430", *LIGHT_STRIPS}
-COLOR_BULBS = {"LB130", "KL125", "KL130", *LIGHT_STRIPS}
-BULBS = {"KL60", "LB100", *VARIABLE_TEMP, *COLOR_BULBS, *LIGHT_STRIPS}
+LIGHT_STRIPS = {"KL400", "KL430"}
+VARIABLE_TEMP = {"LB120", "LB130", "KL120", "KL125", "KL130", "KL135", "KL430"}
+COLOR_BULBS = {"LB130", "KL125", "KL130", "KL135", *LIGHT_STRIPS}
+BULBS = {
+    "KL50",
+    "KL60",
+    "LB100",
+    "LB110",
+    "KL110",
+    *VARIABLE_TEMP,
+    *COLOR_BULBS,
+    *LIGHT_STRIPS,
+}
 
 
-PLUGS = {"HS100", "HS103", "HS105", "HS110", "HS200", "HS210", "EP10", "KP115"}
-STRIPS = {"HS107", "HS300", "KP303", "KP400"}
+PLUGS = {
+    "HS100",
+    "HS103",
+    "HS105",
+    "HS110",
+    "HS200",
+    "HS210",
+    "EP10",
+    "KP115",
+    "KP105",
+    "KP401",
+}
+STRIPS = {"HS107", "HS300", "KP303", "KP400", "EP40"}
 DIMMERS = {"HS220"}
 
 DIMMABLE = {*BULBS, *DIMMERS}
